==> openflowplugin-extension-nicira-0.7.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/src/choice/grouping/src/choice/SrcNxNshNpCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.src.choice.grouping.src.choice;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Boolean;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link SrcNxNshNpCaseBuilder} instances.
 *
 * @see SrcNxNshNpCaseBuilder
 *
 */
public class SrcNxNshNpCaseBuilder implements Builder<SrcNxNshNpCase> {

    private Boolean _nxNshNp;


    Map<Class<? extends Augmentation<SrcNxNshNpCase>>, Augmentation<SrcNxNshNpCase>> augmentation = Collections.emptyMap();

    public SrcNxNshNpCaseBuilder() {
    }
    public SrcNxNshNpCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshNpGrouping arg) {
        this._nxNshNp = arg.isNxNshNp();
    }

    public SrcNxNshNpCaseBuilder(SrcNxNshNpCase base) {
        this._nxNshNp = base.isNxNshNp();
        if (base instanceof SrcNxNshNpCaseImpl) {
            SrcNxNshNpCaseImpl impl = (SrcNxNshNpCaseImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<SrcNxNshNpCase>>, Augmentation<SrcNxNshNpCase>> aug =((AugmentationHolder<SrcNxNshNpCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshNpGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshNpGrouping) {
            this._nxNshNp = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshNpGrouping)arg).isNxNshNp();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshNpGrouping]");
    }

    public Boolean isNxNshNp() {
        return _nxNshNp;
    }
    
    @SuppressWarnings("unchecked")
    public <E extends Augmentation<SrcNxNshNpCase>> E augmentation(Class<E> augmentationType) {
        return (E) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public SrcNxNshNpCaseBuilder setNxNshNp(final Boolean value) {
        this._nxNshNp = value;
        return this;
    }
    
    public SrcNxNshNpCaseBuilder addAugmentation(Class<? extends Augmentation<SrcNxNshNpCase>> augmentationType, Augmentation<SrcNxNshNpCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public SrcNxNshNpCaseBuilder removeAugmentation(Class<? extends Augmentation<SrcNxNshNpCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public SrcNxNshNpCase build() {
        return new SrcNxNshNpCaseImpl(this);
    }

    private static final class SrcNxNshNpCaseImpl implements SrcNxNshNpCase {
    
        private final Boolean _nxNshNp;
    
        private Map<Class<? extends Augmentation<SrcNxNshNpCase>>, Augmentation<SrcNxNshNpCase>> augmentation = Collections.emptyMap();
    
        SrcNxNshNpCaseImpl(SrcNxNshNpCaseBuilder base) {
            this._nxNshNp = base.isNxNshNp();
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<SrcNxNshNpCase> getImplementedInterface() {
            return SrcNxNshNpCase.class;
        }
    
        @Override
        public Boolean isNxNshNp() {
            return _nxNshNp;
        }
        
        @SuppressWarnings("unchecked")
        @Override
        public <E extends Augmentation<SrcNxNshNpCase>> E augmentation(Class<E> augmentationType) {
            return (E) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nxNshNp);
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!SrcNxNshNpCase.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            SrcNxNshNpCase other = (SrcNxNshNpCase)obj;
            if (!Objects.equals(_nxNshNp, other.isNxNshNp())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                SrcNxNshNpCaseImpl otherImpl = (SrcNxNshNpCaseImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<SrcNxNshNpCase>>, Augmentation<SrcNxNshNpCase>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("SrcNxNshNpCase");
            CodeHelpers.appendValue(helper, "_nxNshNp", _nxNshNp);
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}

==> openflowplugin-extension-nicira-0.7.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/src/choice/grouping/src/choice/SrcNxNshNpCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.src.choice.grouping.src.choice;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Boolean;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link SrcNxNshNpCaseBuilder} instances.
 *
 * @see SrcNxNshNpCaseBuilder
 *
 */
public class SrcNxNshNpCaseBuilder implements Builder<SrcNxNshNpCase> {

    private Boolean _nxNshNp;


    Map<Class<? extends Augmentation<SrcNxNshNpCase>>, Augmentation<SrcNxNshNpCase>> augmentation = Collections.emptyMap();

    public SrcNxNshNpCaseBuilder() {
    }
    public SrcNxNshNpCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshNpGrouping arg) {
        this._nxNshNp = arg.isNxNshNp();
    }

    public SrcNxNshNpCaseBuilder(SrcNxNshNpCase base) {
        this._nxNshNp = base.isNxNshNp();
        if (base instanceof SrcNxNshNpCaseImpl) {
            SrcNxNshNpCaseImpl impl = (SrcNxNshNpCaseImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<SrcNxNshNpCase>>, Augmentation<SrcNxNshNpCase>> aug =((AugmentationHolder<SrcNxNshNpCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshNpGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshNpGrouping) {
            this._nxNshNp = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshNpGrouping)arg).isNxNshNp();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmNxNshNpGrouping]");
    }

    public Boolean isNxNshNp() {
        return _nxNshNp;
    }
    
    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<SrcNxNshNpCase>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public SrcNxNshNpCaseBuilder setNxNshNp(final Boolean value) {
        this._nxNshNp = value;
        return this;
    }
    
    public SrcNxNshNpCaseBuilder addAugmentation(Class<? extends Augmentation<SrcNxNshNpCase>> augmentationType, Augmentation<SrcNxNshNpCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public SrcNxNshNpCaseBuilder removeAugmentation(Class<? extends Augmentation<SrcNxNshNpCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public SrcNxNshNpCase build() {
        return new SrcNxNshNpCaseImpl(this);
    }

    private static final class SrcNxNshNpCaseImpl implements SrcNxNshNpCase {
    
        private final Boolean _nxNshNp;
    
        private Map<Class<? extends Augmentation<SrcNxNshNpCase>>, Augmentation<SrcNxNshNpCase>> augmentation = Collections.emptyMap();
    
        SrcNxNshNpCaseImpl(SrcNxNshNpCaseBuilder base) {
            this._nxNshNp = base.isNxNshNp();
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<SrcNxNshNpCase> getImplementedInterface() {
            return SrcNxNshNpCase.class;
        }
    
        @Override
        public Boolean isNxNshNp() {
            return _nxNshNp;
        }
        
        @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
        @Override
        public <E$$ extends Augmentation<SrcNxNshNpCase>> E$$ augmentation(Class<E$$> augmentationType) {
            return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nxNshNp);
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!SrcNxNshNpCase.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            SrcNxNshNpCase other = (SrcNxNshNpCase)obj;
            if (!Objects.equals(_nxNshNp, other.isNxNshNp())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                SrcNxNshNpCaseImpl otherImpl = (SrcNxNshNpCaseImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<SrcNxNshNpCase>>, Augmentation<SrcNxNshNpCase>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("SrcNxNshNpCase");
            CodeHelpers.appendValue(helper, "_nxNshNp", _nxNshNp);
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}
